==> metapredict-2.61.tar.gz: metapredict-2.61/metapredict/tests/test_batch_vs_single.py <==

# Import package, test suite, and other packages as needed
from . import local_data
import numpy as np
import os

from metapredict.metapredict_exceptions import MetapredictError
from metapredict.backend import batch_predict
import protfasta

from packaging import version
import torch

import metapredict as meta


current_filepath = os.getcwd()
fasta_filepath = "{}/input_data/testing.fasta".format(current_filepath)

onehundred_seqs = "{}/input_data/test_seqs_100.fasta".format(current_filepath)
onehundred_scores = "{}/input_data/test_scores_100.npy".format(current_filepath)


from . import build_seq

def score_compare(s1, s2):
    """
    Function which compares two lists/arrays with an error-tollerance
    of 1e-3. Used for comparing disorder profiles

    Parameters
    ------------
    s1 : list/np.array
        Numerical vector/array/list 1

    s2 : list/np.array
        Numerical vector/array/list 2

    Returns
    ----------
    Bool
        Returns true if all elements are less than 1e-3, else 
        returns False
    
    """
    
    return np.allclose(np.array(s1), np.array(s2), atol=1e-3)
    
    


def test_size_filter():
    """
    Function that tests the size_filter function in batch_predict
    """
    
    
    in_seqs = ['A','AA','AAA','A','AAAAAA']
    out = batch_predict.size_filter(in_seqs)
    assert len(out[1]) == 2
    assert len(out[2]) == 1
    assert len(out[3]) == 1
    assert len(out[6]) == 1

## test the new metapredict predictor
def test_metapredict_predictor():
    """
    Simple one -off test make sure we predict disorder scores that 

    """

    seq = 'RDCAPNNGKKMDNQQHGDVSNQSDNRDSVQQQPPQMAGSQERQKSTESQQSPRSKENKQQAGHSHPESMPRSMSEKEPEMQHDESTGMQNHNRGMQSQDP'
    assert meta.predict_disorder(seq) == local_data.S2

    test = {'test':seq}
    
    out = batch_predict.batch_predict(test)

    # using a tolerance of 1e-3 because batch works on single and on double
    # precision, but if no pair of residues is different than 1e-4 these are
    # functionally identical
    #assert np.allclose(out['test'][1], np.array(local_data.S2), atol=1e-3)
    #assert np.allclose(out['test'][1], np.array(meta.predict_disorder(seq)), atol=1e-3)
    assert score_compare(out['test'][1], local_data.S2)
    assert score_compare(out['test'][1], meta.predict_disorder(seq))


def test_batch_prediction():

    nseqs=100
    
    seqs = {}
    for idx, _ in enumerate(range(nseqs)):
        s = build_seq()
        seqs[idx] = s

    # size-collect should be available everywhere, so test this regardless
    preds = batch_predict.batch_predict(seqs, force_mode='size-collect')
    
    for s in seqs:
        single = meta.predict_disorder(seqs[s])
        assert score_compare(np.array(preds[s][1]), single)

    # if we're on toruch 1.11 or higher also test pad-n-pack 
    if version.parse(torch.__version__) >= version.parse("1.11.0"):
        preds = batch_predict.batch_predict(seqs, force_mode='pad-n-pack')    
        for s in seqs:
            single = meta.predict_disorder(seqs[s])
            assert score_compare(np.array(preds[s][1]), single)        

def test_batch_idrs():

    seqs = {}
    for idx, _ in enumerate(range(100)):
        s = build_seq()
        seqs[idx] = s

    # mode 1 should be available everywhere, so test this regardless
    preds = batch_predict.batch_predict(seqs, return_domains=True, force_mode='size-collect')
    
    for s in seqs:
        single = meta.predict_disorder_domains(seqs[s])

        p = preds[s]
        for idx in range(len(p.disordered_domains)):
            assert p.disordered_domains[idx] == single.disordered_domains[idx]
            assert p.disordered_domain_boundaries[idx] == single.disordered_domain_boundaries[idx] 

        for idx in range(len(p.folded_domains)):
            assert p.folded_domains[idx] == single.folded_domains[idx]
            assert p.folded_domain_boundaries[idx] == single.folded_domain_boundaries[idx]

    if version.parse(torch.__version__) >= version.parse("1.11.0"):
        preds = batch_predict.batch_predict(seqs, return_domains=True, force_mode='pad-n-pack')

        for s in seqs:
            single = meta.predict_disorder_domains(seqs[s])

            p = preds[s]
            for idx in range(len(p.disordered_domains)):
                assert p.disordered_domains[idx] == single.disordered_domains[idx]

                assert p.disordered_domain_boundaries[idx] == single.disordered_domain_boundaries[idx] 

            for idx in range(len(p.folded_domains)):
                assert p.folded_domains[idx] == single.folded_domains[idx]
                assert p.folded_domain_boundaries[idx] == single.folded_domain_boundaries[idx]
        
            
            

def test_batch_prediction_mode1_vs_mode2():
    nseqs=100
    
    if version.parse(torch.__version__) >= version.parse("1.11.0"):
    
        seqs = {}
        for idx, _ in enumerate(range(nseqs)):
            s = build_seq()
            seqs[idx] = s
        
        preds_v1 = batch_predict.batch_predict(seqs, force_mode=1, print_performance=True)
        preds_v2 = batch_predict.batch_predict(seqs, force_mode=2, print_performance=True)
        for s in seqs:

            # note even here <1e-3 seems to be the magic number in terms of inprecision
            # for predictions 
            assert score_compare(preds_v1[s][1], preds_v2[s][1]) 



def test_big_test_batch():
    """
    Big tests that compares previously computed disordered scores for 100 sequences
    with the current testable version. This is the most robust test to ensure that
    the current version reproduces scores of other versions of metapredict
    

    """

    scores = np.load(onehundred_scores, allow_pickle=True).tolist()
    seqs = protfasta.read_fasta(onehundred_seqs)


    batch_predictions = batch_predict.batch_predict(seqs)

    for idx, k in enumerate(seqs):
        assert np.allclose(scores[idx], batch_predictions[k][1], atol=1e-3)

==> metapredict-2.62.tar.gz: metapredict-2.62/metapredict/tests/test_batch_vs_single.py <==

# Import package, test suite, and other packages as needed
from . import local_data
import numpy as np
import os

from metapredict.metapredict_exceptions import MetapredictError
from metapredict.backend import batch_predict
import protfasta

from packaging import version
import torch

import metapredict as meta


current_filepath = os.getcwd()
fasta_filepath = "{}/input_data/testing.fasta".format(current_filepath)

onehundred_seqs = "{}/input_data/test_seqs_100.fasta".format(current_filepath)
onehundred_scores = "{}/input_data/test_scores_100.npy".format(current_filepath)


from . import build_seq

def score_compare(s1, s2):
    """
    Function which compares two lists/arrays with an error-tollerance
    of 1e-3. Used for comparing disorder profiles

    Parameters
    ------------
    s1 : list/np.array
        Numerical vector/array/list 1

    s2 : list/np.array
        Numerical vector/array/list 2

    Returns
    ----------
    Bool
        Returns true if all elements are less than 1e-3, else 
        returns False
    
    """
    
    return np.allclose(np.array(s1), np.array(s2), atol=1e-3)
    
    


def test_size_filter():
    """
    Function that tests the size_filter function in batch_predict
    """
    
    
    in_seqs = ['A','AA','AAA','A','AAAAAA']
    out = batch_predict.size_filter(in_seqs)
    assert len(out[1]) == 2
    assert len(out[2]) == 1
    assert len(out[3]) == 1
    assert len(out[6]) == 1

## test the new metapredict predictor
def test_metapredict_predictor():
    """
    Simple one -off test make sure we predict disorder scores that 

    """

    seq = 'RDCAPNNGKKMDNQQHGDVSNQSDNRDSVQQQPPQMAGSQERQKSTESQQSPRSKENKQQAGHSHPESMPRSMSEKEPEMQHDESTGMQNHNRGMQSQDP'
    assert meta.predict_disorder(seq) == local_data.S2

    test = {'test':seq}
    
    out = batch_predict.batch_predict(test)

    # using a tolerance of 1e-3 because batch works on single and on double
    # precision, but if no pair of residues is different than 1e-4 these are
    # functionally identical
    #assert np.allclose(out['test'][1], np.array(local_data.S2), atol=1e-3)
    #assert np.allclose(out['test'][1], np.array(meta.predict_disorder(seq)), atol=1e-3)
    assert score_compare(out['test'][1], local_data.S2)
    assert score_compare(out['test'][1], meta.predict_disorder(seq))


def test_batch_prediction():

    nseqs=100
    
    seqs = {}
    for idx, _ in enumerate(range(nseqs)):
        s = build_seq()
        seqs[idx] = s

    # size-collect should be available everywhere, so test this regardless
    preds = batch_predict.batch_predict(seqs, force_mode='size-collect')
    
    for s in seqs:
        single = meta.predict_disorder(seqs[s])
        assert score_compare(np.array(preds[s][1]), single)

    # if we're on toruch 1.11 or higher also test pack-n-pad 
    if version.parse(torch.__version__) >= version.parse("1.11.0"):
        preds = batch_predict.batch_predict(seqs, force_mode='pack-n-pad')    
        for s in seqs:
            single = meta.predict_disorder(seqs[s])
            assert score_compare(np.array(preds[s][1]), single)        

def test_batch_idrs():

    seqs = {}
    for idx, _ in enumerate(range(100)):
        s = build_seq()
        seqs[idx] = s

    # mode 1 should be available everywhere, so test this regardless
    preds = batch_predict.batch_predict(seqs, return_domains=True, force_mode='size-collect')
    
    for s in seqs:
        single = meta.predict_disorder_domains(seqs[s])

        p = preds[s]
        for idx in range(len(p.disordered_domains)):
            assert p.disordered_domains[idx] == single.disordered_domains[idx]
            assert p.disordered_domain_boundaries[idx] == single.disordered_domain_boundaries[idx] 

        for idx in range(len(p.folded_domains)):
            assert p.folded_domains[idx] == single.folded_domains[idx]
            assert p.folded_domain_boundaries[idx] == single.folded_domain_boundaries[idx]

    if version.parse(torch.__version__) >= version.parse("1.11.0"):
        preds = batch_predict.batch_predict(seqs, return_domains=True, force_mode='pack-n-pad')

        for s in seqs:
            single = meta.predict_disorder_domains(seqs[s])

            p = preds[s]
            for idx in range(len(p.disordered_domains)):
                assert p.disordered_domains[idx] == single.disordered_domains[idx]

                assert p.disordered_domain_boundaries[idx] == single.disordered_domain_boundaries[idx] 

            for idx in range(len(p.folded_domains)):
                assert p.folded_domains[idx] == single.folded_domains[idx]
                assert p.folded_domain_boundaries[idx] == single.folded_domain_boundaries[idx]
        
            
            

def test_batch_prediction_mode1_vs_mode2():
    nseqs=100
    
    if version.parse(torch.__version__) >= version.parse("1.11.0"):
    
        seqs = {}
        for idx, _ in enumerate(range(nseqs)):
            s = build_seq()
            seqs[idx] = s
        
        preds_v1 = batch_predict.batch_predict(seqs, force_mode='size-collect', print_performance=True)
        preds_v2 = batch_predict.batch_predict(seqs, force_mode='pack-n-pad', print_performance=True)
        for s in seqs:

            # note even here <1e-3 seems to be the magic number in terms of inprecision
            # for predictions 
            assert score_compare(preds_v1[s][1], preds_v2[s][1]) 



def test_big_test_batch():
    """
    Big tests that compares previously computed disordered scores for 100 sequences
    with the current testable version. This is the most robust test to ensure that
    the current version reproduces scores of other versions of metapredict
    

    """

    scores = np.load(onehundred_scores, allow_pickle=True).tolist()
    seqs = protfasta.read_fasta(onehundred_seqs)


    batch_predictions = batch_predict.batch_predict(seqs)

    for idx, k in enumerate(seqs):
        assert np.allclose(scores[idx], batch_predictions[k][1], atol=1e-3)
